package com.jeeplus.test.cw.contractRegistration.service;

import com.jeeplus.sys.service.dto.UserDTO;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.sys.utils.UserUtils;
import com.jeeplus.test.cw.contractRegistration.domain.ContractFile;
import com.jeeplus.test.cw.contractRegistration.domain.ContractInfo;
import com.jeeplus.test.cw.contractRegistration.mapper.ContractFileMapper;
import com.jeeplus.test.workContract.domain.WorkContractFile;
import com.jeeplus.test.workContract.service.dto.WorkContractFileDto;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.UUID;

/**
 * @author: 王强
 * @create: 2022-11-10 16:12
 **/
@Service
public class ContractFileService {

    @Resource
    private ContractFileMapper mapper;

    /**
     * 根据id修改status
     */
    public void updateStatusById(ContractFile contractFile) {
        mapper.updateStatusById(contractFile.getId(), contractFile.getFiledType());
    }

    public String saveInfo(ContractFile contractFile) throws Exception {
        if (StringUtils.isNotEmpty(contractFile.getId())) {
            ContractFile info = mapper.selectFileByContractInfoId(contractFile.getId());
            if (info != null) {
                return update(contractFile, info.getId());
            }
        }
        return add(contractFile);
    }

    /**
     * 合同登记新增
     */
    @Transactional(rollbackFor = Exception.class)
    public String add(ContractFile contractFile) throws Exception{
        //获取当前登录人信息
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        String id = UUID.randomUUID().toString().replace("-", "");
        ContractFile file = new ContractFile();
        BeanUtils.copyProperties(contractFile, file);
        file.setId(id);
        file.setCreateBy(userDTO.getId());
        file.setCreateDate(new Date());
        file.setUpdateBy(userDTO.getId());
        file.setUpdateDate(new Date());
        mapper.insert(file);
        return id;
    }

    /**
     * 合同登记归档修改
     */
    @Transactional(rollbackFor = Exception.class)
    public String update(ContractFile contractFile, String id) {
        //获取当前登录人信息
        UserDTO userDTO = UserUtils.getCurrentUserDTO();
        ContractFile file = new ContractFile();
        BeanUtils.copyProperties(contractFile, file);
        file.setId(id);
        file.setUpdateBy(userDTO.getId());
        file.setUpdateDate(new Date());
        mapper.updateById(file);
        return file.getId();
    }
}
